==> igniteui-angular-charts-16.0.0.tgz: package/esm2015/lib/WilliamsPercentRIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { WilliamsPercentRIndicatorStrategy } from "./WilliamsPercentRIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
/**
 * @hidden
 */
export let WilliamsPercentRIndicator = /*@__PURE__*/ (() => {
    class WilliamsPercentRIndicator extends StrategyBasedIndicator {
        get_ul() {
            return new WilliamsPercentRIndicatorStrategy();
        }
        get ul() {
            return this.get_ul();
        }
        get_uy() {
            return WilliamsPercentRIndicator.$;
        }
        get uy() {
            return this.get_uy();
        }
        get u6() {
            return typeGetValue(this.c(WilliamsPercentRIndicator.u7));
        }
        set u6(a) {
            this.h(WilliamsPercentRIndicator.u7, a);
        }
        ur() {
            return this.u6;
        }
        u0(a) {
            this.u6 = a;
        }
    }
    WilliamsPercentRIndicator.$t = markType(WilliamsPercentRIndicator, 'WilliamsPercentRIndicator', StrategyBasedIndicator.$);
    WilliamsPercentRIndicator.u7 = StrategyBasedIndicator.u3(14, WilliamsPercentRIndicator.$);
    return WilliamsPercentRIndicator;
})();

==> igniteui-angular-charts-17.2.1.tgz: package/esm2015/lib/WilliamsPercentRIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { WilliamsPercentRIndicatorStrategy } from "./WilliamsPercentRIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
/**
 * @hidden
 */
export let WilliamsPercentRIndicator = /*@__PURE__*/ (() => {
    class WilliamsPercentRIndicator extends StrategyBasedIndicator {
        bg() {
            return new WilliamsPercentRIndicator();
        }
        get_yz() {
            return new WilliamsPercentRIndicatorStrategy();
        }
        get yz() {
            return this.get_yz();
        }
        get_zc() {
            return WilliamsPercentRIndicator.$;
        }
        get zc() {
            return this.get_zc();
        }
        get zk() {
            return typeGetValue(this.c(WilliamsPercentRIndicator.zl));
        }
        set zk(a) {
            this.h(WilliamsPercentRIndicator.zl, a);
        }
        y5() {
            return this.zk;
        }
        ze(a) {
            this.zk = a;
        }
    }
    WilliamsPercentRIndicator.$t = markType(WilliamsPercentRIndicator, 'WilliamsPercentRIndicator', StrategyBasedIndicator.$);
    WilliamsPercentRIndicator.zl = StrategyBasedIndicator.zh(14, WilliamsPercentRIndicator.$);
    return WilliamsPercentRIndicator;
})();
